summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteblacklister.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopeteblacklister.h')
-rw-r--r--kopete/libkopete/kopeteblacklister.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kopete/libkopete/kopeteblacklister.h b/kopete/libkopete/kopeteblacklister.h
index ed3e5566..c2df1bca 100644
--- a/kopete/libkopete/kopeteblacklister.h
+++ b/kopete/libkopete/kopeteblacklister.h
@@ -16,7 +16,7 @@
#ifndef KOPETEBLACKLISTER_H
#define KOPETEBLACKLISTER_H
-#include <qobject.h>
+#include <tqobject.h>
namespace Kopete
{
@@ -51,10 +51,10 @@ public:
* Create an instance, and read the blacklist from disk if it exists.
* @param protocolId is the ID of the protocol owning accountId
* @param accountId is the ID of the owning Account.
* @param parent The QObject parent for this class.
* @param name The QObject name for this class.
*/
- BlackLister( const QString &protocolId, const QString &accountId, QObject *parent = 0, const char *name = 0 );
+ BlackLister( const TQString &protocolId, const TQString &accountId, TQObject *parent = 0, const char *name = 0 );
~BlackLister();
/**
@@ -65,7 +65,7 @@ public:
/**
* \return @c true if the contact with ID @p contactId is blocked, @c false otherwise.
*/
- bool isBlocked( const QString &contactId );
+ bool isBlocked( const TQString &contactId );
public slots:
/**
@@ -74,7 +74,7 @@ public slots:
* This function emits the @ref contactAdded() signal.
* @param contactId is the ID of the contact to be added to the list.
*/
- void addContact( const QString &contactId );
+ void addContact( const TQString &contactId );
/**
* @overload
@@ -93,7 +93,7 @@ public slots:
/**
* @overload
*/
- void removeContact( const QString &contactId );
+ void removeContact( const TQString &contactId );
signals:
/**
@@ -102,7 +102,7 @@ signals:
* Connect to this signal if you want to perform additional actions,
* and you prefer not to derive from this class.
*/
- void contactAdded( const QString &contactId );
+ void contactAdded( const TQString &contactId );
/**
* \brief A contact has been removed from the list
@@ -110,7 +110,7 @@ signals:
* Connect to this signal if you want to perform additional actions,
* and you prefer not to derive from this class.
*/
- void contactRemoved( const QString &contactId );
+ void contactRemoved( const TQString &contactId );
private:
void saveToDisk();
@@ -51,10 +51,10 @@ public:
* @param protocolId is the ID of the protocol owning accountId
* @param accountId is the ID of the owning Account.
- * @param parent The QObject parent for this class.
- * @param name The QObject name for this class.
+ * @param parent The TQObject parent for this class.
+ * @param name The TQObject name for this class.
*/